@@ -33,6 +33,8 @@
 //!
 //! The above example occurs because "ã" is technically made up of two UTF-8 scalar values.
 
+#![no_std]
+
 /// Provides a `substring` method.
 ///
 /// The `substring` method obtains a string slice of characters within the range specified by
@@ -80,7 +82,7 @@ impl Substring for str {
 
 #[cfg(test)]
 mod tests {
-    use crate::Substring;
+    use Substring;
 
     #[test]
     fn test_substring() {
